#ifndef MAIN_WINDOW_H
#define MAIN_WINDOW_H

#include <QMainWindow>
#include <QFile>
#include <QDebug>
#include <QFileDialog>
#include <QKeyEvent>
#include <QVector>
#include <QStack>
#include <QTableWidgetItem>
#include <QBrush>
#include <QColor>
#include <QWindowStateChangeEvent>
#include "ui_Matricel.h"
#include "MatrixResizeDialog.h"


class MainWindow : public QMainWindow, public Ui::Matricel
{
    Q_OBJECT

    public:
        /// Constructor
        MainWindow();

        /// Destructor
        virtual ~MainWindow() {}

    protected:
        /// Method used to capture the ESC key to quit
        virtual bool eventFilter(QObject *obj, QEvent *e);

    protected slots:
        /// Method used to open CSV files into the QTableWidget
        void on_actionLoad_triggered(bool checked);

        /// Method used to save edits to the QTableWidget to a file
        void on_actionSave_triggered(bool checked);

        /// Method used to quit the program
        void on_actionQuit_triggered(bool checked);

        /// Method used to display the matrix resize dialog
        void on_actionSize_triggered(bool checked);

        /// Method used to indicate that a cell's state changed
        void on_tableWidget_cellChanged(int row, int column);

        /// Method used whenever the user requests a resize of the QTableWidget
        void resized(int row, int col);

    private:
        // (x,y) coordinates of edits from least to most recent
        QVector<QPair<int,int>> _edits;

        /// Dialog used to resize the matrix to user specifications
        MatrixResizeDialog *_mrd;
};

#endif //MAIN_WINDOW_H
